@@ -1,5 +1,7 @@
 #!/bin/sh
-PYVER=26
+PYVER=25
+# This is used to select the prepackaged python tarball
+MYPYVER=25
 PYTHON=/c/Python$PYVER/python.exe
 
 build() {
@@ -18,11 +20,23 @@ prepare_installer() {
   rm win32 -rf
   make DESTDIR=win32 prefix="" install skipmanual=yes PYTHON_INCLUDES=-I/c/Python$PYVER/include
   mkdir win32/python
-  (cd win32/python && tar zxf ../../../my-python-26.tgz)
+  (cd win32/python && tar zxf ../../../my-python-$MYPYVER.tgz)
+  mv win32/python/DLLs win32/bin
+  mv win32/python/Lib win32/bin
+  mv win32/python/libs win32/bin
+  mv win32/python/LICENSE.txt win32/LICENSE.python.txt
+  mv win32/python/NEWS.txt win32/NEWS.python.txt
+  mv win32/python/README.txt win32/README.python.txt
+  mv win32/python/python.exe win32/bin
+  mv win32/python/pythonw.exe win32/bin
+  mv win32/python/w9xpopen.exe win32/bin
   $PYTHON tools/get-gtk-files.py bin
   $PYTHON tools/get-gtk-files.py unpack
   mv win32/zlib-1.2.4/zlib1.dll win32/bin
-  cp -a ../pygtk-stuff/* win32/python/lib/site-packages
+  # Move these so CSound can find python25.dll
+  mv win32/python/python25.dll win32/bin
+  mv win32/python/msvcr71.dll win32/bin
+  cp -a ../pygtk-stuff/* win32/bin/lib/site-packages
   (cp solfege/soundcard/winmidi.pyd win32/share/solfege/solfege/soundcard)
   cp win32-start-solfege.pyw win32/bin
   cp solfegedebug.bat win32/bin/
@@ -31,6 +45,7 @@ prepare_installer() {
   echo "gtk-theme-name = \"MS-Windows\""  > win32/etc/gtk-2.0/gtkrc
   (cd win32 && find -name *.pyc | xargs rm)
   $PYTHON tools/trim_win32_installer.py
+  rm -rf win32/python
   echo "Now you must double click the file windowsinstaller.iss and"
   echo "build the installer"
 }
